@@ -13,6 +13,7 @@
 ###############################################################################
 
 #' Calculate 'bias' of grid as defined by Slater (1977). 
+#'
 #' "Bias records a tendency for reponses to accumulate at one end of the 
 #' grading scale" (Slater, 1977, p.88). 
 #'
@@ -48,6 +49,7 @@ indexBias <- function(x, min, max, digits=2){
 
 
 #' Calculate 'variability' of a grid as defined by Slater (1977).
+#'
 #' Variability records a tendency for the responses to gravitate 
 #' towards both end of the gradings scale. (Slater, 1977, p.88).
 #'
@@ -91,7 +93,9 @@ indexVariability <- function(x, min, max, digits=2){
 ###  						              OTHER INDICES          							          ###
 ###############################################################################
 
-#' Percentage of Variance Accounted for by the First Factor (PVAFF) is used as 
+#' Percentage of Variance Accounted for by the First Factor (PVAFF)
+#'
+#' The PVAFF is used as 
 #' a measure of cognitive complexity. It was introduced in an unpublished
 #' PhD thesis by Jones (1954, cit. Bonarius, 1965).
 #' To calculate it, the 'first factor' is extracted from the construct 
@@ -142,7 +146,7 @@ indexVariability <- function(x, min, max, digits=2){
 indexPvaff <- function(x, output=1, digits=2){
 	if (!inherits(x, "repgrid")) 
 		stop("Object must be of class 'repgrid'")
-  cr <- constructCor(x, out=0)
+  cr <- constructCor(x, output=0)
   sv <- svd(cr)$d 
   pvaff <- sv[1]^2/sum(sv^2)
   if (output == 1){
@@ -161,12 +165,14 @@ indexPvaff <- function(x, output=1, digits=2){
 indexPvaff2 <- function(x){
 	if (!inherits(x, "repgrid")) 
 		stop("Object must be of class 'repgrid'")
-	r <- constructCor(x, out=0)
+	r <- constructCor(x, output=0)
   sv <- princomp(r)$sdev
   pvaff <- sv[1]^2/sum(sv^2)
 }
 
 
+#' Calculate intensity index.
+#'
 #' The Intensity index has been suggested by Bannister (1960) as a 
 #' measure of the amount of construct linkage. Bannister suggested 
 #' that the score reflects the degree of organization of the construct 
@@ -241,12 +247,12 @@ indexPvaff2 <- function(x){
 indexIntensity <- function(x, rc=FALSE, output=TRUE, trim=30, digits=2){
   if (!inherits(x, "repgrid")) 
 		stop("Object must be of class 'repgrid'")
-	cr <- constructCor(x, trim=trim, digits=8, out=0)
+	cr <- constructCor(x, trim=trim, digits=8, output=0)
 	nc <- getNoOfConstructs(x)
 	diag(cr) <- 0                                           # out zeros in diagonal (won't have an effect)
   c.int <- apply(cr^2, 2, function(x) sum(x) / (nc-1))    # sum of squared correlations / nc -1 
 	
-	er <- elementCor(x, rc=rc, trim=trim, digits=8, out=0)
+	er <- elementCor(x, rc=rc, trim=trim, digits=8, output=0)
 	ne <- getNoOfElements(x)
 	diag(er) <- 0                                           # out zeros in diagonal (won't have an effect)
   e.int <- apply(er^2, 2, function(x) sum(x) / (ne-1))    # sum of squared correlations / ne -1 
@@ -285,6 +291,8 @@ indexIntensity <- function(x, rc=FALSE, output=TRUE, trim=30, digits=2){
 
 
 ### Slater distance ###
+#' Calculate Slater distance.
+#'
 #' The euclidean distance is often used as a measure of similarity  
 #' between elements (see \code{\link{distance}}.
 #' A drawback of this measure is that it 
@@ -376,7 +384,7 @@ distanceSlater <- function(x, trim=10, indexcol=FALSE, digits=2, output=1,
                            upper=TRUE){
   if (!inherits(x, "repgrid")) 
 		stop("Object must be of class 'repgrid'")
-	E <- distance(x, along=2, digits = 10, out=0)
+	E <- distance(x, along=2, digits = 10, output=0)
 	m <- getNoOfElements(x)
 	D <- center(x)              # row centering of grid data
 	S <- sum(diag(t(D) %*% D))  
@@ -425,6 +433,8 @@ distanceSlater <- function(x, trim=10, indexcol=FALSE, digits=2, output=1,
 
 
 ### Hartmann distance ###
+#' Calculate Hartmann distance
+#' 
 #' Hartmann (1992) showed in a Monte Carlo study that Slater distances
 #' (see \code{\link{distanceSlater}}) based on random grids, for 
 #' which Slater coined the expression quasis, have a skewed distribution,
@@ -545,7 +555,7 @@ distanceHartmann <- function(x, rep=100, meantype=2, quant=c(.05, .5, .95),
                               digits=2, output=1, progress=TRUE, upper=TRUE){
   if (!inherits(x, "repgrid")) 
 		stop("Object must be of class 'repgrid'")
-  D <- distanceSlater(x, digits=10, out=0)
+  D <- distanceSlater(x, digits=10, output=0)
 
   range <- getScale(x)            # get in and max scale value
   nc <- getNoOfConstructs(x)
@@ -654,6 +664,8 @@ distanceHartmann <- function(x, rep=100, meantype=2, quant=c(.05, .5, .95),
 
 ### Power transformed Hartmann distance ###
 #
+#' Calculate power-transformed Hartmann distances.
+#'
 #' Hartmann (1992) suggested a transformation of Slater (1977) distances 
 #' to make them independent from the size of a grid. Hartmann distances are supposed
 #' to yield stable cutoff values used to determine 'significance' of inter-element
@@ -781,7 +793,8 @@ distanceNormalized <- function(x, rep=100, quant=c(.05, .5, .95),
 		stop("Object must be of class 'repgrid'")
 
   # calculate Hartmann and Slater distances
-  h <- distanceHartmann(x, rep=rep, digits=10, prob=prob, quant=quant, out=0)
+  h <- distanceHartmann(x, rep=rep, digits=10, prob=prob, 
+                        progress=progress, quant=quant, output=0)
   
   # optimal lambda for Box-Cox transformation. Add constant as only defined for positive values
   constant <- abs(min(c(h$h.vals, h$hartmann))) + 0.00001
@@ -870,6 +883,9 @@ indexConflict1Out1 <- function(res){
   cat("\nProportion of imbalanced triads:", res[[4]] * 100, "%")
 }
 
+
+#' Conflict measure as proposed by Slade and Sheehan (1979) 
+#'
 #' The first approach to mathematically derive a conflict measure based on
 #' grid data was presented by Slade and Sheehan (1979). Their 
 #' operationalization is based on an approach by Lauterbach (1975) 
@@ -940,7 +956,7 @@ indexConflict1Out1 <- function(res){
 indexConflict1 <- function(x, digits=1, output=1){
   if (!inherits(x, "repgrid")) 
 		stop("Object must be of class 'repgrid'")
-	r <- constructCor(x, out=0)             # construct correlation matrix
+	r <- constructCor(x, output=0)          # construct correlation matrix
 	z <- fisherz(r)
 	nc <- getNoOfConstructs(x)              # number of constructs
 	comb <- t(combn(nc, 3))                 # all possible correlation triads
@@ -991,6 +1007,8 @@ indexConflict2Out2 <- function(res){
 }
 
 
+#' Conflict measure as proposed by Bassler et al. (1992). 
+#'
 #' The function calculates the conflict measure as devised
 #' by Bassler et al. (1992). It is an improved version of the ideas
 #' by Slade and Sheehan (1979) that have been implemented in
@@ -1070,7 +1088,7 @@ indexConflict2Out2 <- function(res){
 indexConflict2 <- function(x, crit=.03, digits=1, output=1){
   if (!inherits(x, "repgrid")) 
 		stop("Object must be of class 'repgrid'")
-	r <- constructCor(x, out=0)             # construct correlation matrix
+	r <- constructCor(x, output=0)          # construct correlation matrix
 	z <- fisherz(r)
 	nc <- getNoOfConstructs(x)              # number of constructs
 	comb <- t(combn(nc, 3))                 # all possible correlation triads
@@ -1109,7 +1127,8 @@ indexConflict2 <- function(x, crit=.03, digits=1, output=1){
 }
 
 
-
+#' Conflict measure as proposed by Bell (2004). 
+#'
 #' Measure of conflict or inconsistency as proposed by Bell (2004).
 #' The identification of conflict is based on distances rather than 
 #' correlations as in other measures of conflict \code{\link{indexConflict1}}
@@ -1417,7 +1436,7 @@ indexConflict3 <- function(x, p=2, output=1,
           print(as.data.frame(formatMatrix(x$disc, 
                               rnames=paste("c", seq_len(nrow(x$disc)), sep=""), 
                               cnames=paste("e", seq_len(ncol(x$disc)), sep=""),
-                              pre.ind=c(F,F),
+                              pre.index=c(F,F),
                               mode=2, diag=F), stringsAsFactors=F))
         }
         cat("\nAv. level of discrepancy:   ", x$avg, "\n")
@@ -1455,8 +1474,8 @@ indexConflict3 <- function(x, p=2, output=1,
 #
 indexDilemmaShowCorrelationDistribution <- function(x, e1, e2)
 {
-  rc.including <- constructCor(x, out=0)  
-  rc.excluding <- constructCor(x[, -c(e1, e2)], out=0)
+  rc.including <- constructCor(x, output=0)  
+  rc.excluding <- constructCor(x[, -c(e1, e2)], output=0)
   rc.inc.vals <- abs(rc.including[lower.tri(rc.including)])
   rc.exc.vals <- abs(rc.excluding[lower.tri(rc.excluding)])
 
@@ -1530,8 +1549,9 @@ indexDilemmaInternal <- function(x, self, ideal,
 
   # inter-construct correlations including and excluding 
   # the elements self and ideal self
-  rc.include <- constructCor(x, digits=digits, out=0)  
-  rc.exclude <- constructCor(x[, -c(self, ideal)], digits=digits, out=0)
+  rc.include <- constructCor(x, digits=digits, output=0)  
+  rc.exclude <- constructCor(x[, -c(self, ideal)], digits=digits, 
+                             output=0)
   
   # correlations to use for evaluation
   if (exclude)
@@ -1687,6 +1707,8 @@ indexDilemmaOut2 <- function(res, exclude){
 }
 
 
+#' Implicative Dilemmas
+#'
 #' Implicative dilemmas are closely related to the notion of 
 #' conflict. An implicative dilemma arises when a desired change on one 
 #' construct is associated with an undesired 
